"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from fastly.exceptions import ApiAttributeError



class Results(ModelNormal):
    """NOTE: This class is auto generated.
    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'requests': (int,),  # noqa: E501
            'hits': (int,),  # noqa: E501
            'hits_time': (float,),  # noqa: E501
            'miss': (int,),  # noqa: E501
            'miss_time': (float,),  # noqa: E501
            '_pass': (int,),  # noqa: E501
            'pass_time': (float,),  # noqa: E501
            'errors': (int,),  # noqa: E501
            'restarts': (int,),  # noqa: E501
            'hit_ratio': (float, none_type,),  # noqa: E501
            'bandwidth': (int,),  # noqa: E501
            'body_size': (int,),  # noqa: E501
            'header_size': (int,),  # noqa: E501
            'req_body_bytes': (int,),  # noqa: E501
            'req_header_bytes': (int,),  # noqa: E501
            'resp_body_bytes': (int,),  # noqa: E501
            'resp_header_bytes': (int,),  # noqa: E501
            'bereq_body_bytes': (int,),  # noqa: E501
            'bereq_header_bytes': (int,),  # noqa: E501
            'uncacheable': (int,),  # noqa: E501
            'pipe': (int,),  # noqa: E501
            'synth': (int,),  # noqa: E501
            'tls': (int,),  # noqa: E501
            'tls_v10': (int,),  # noqa: E501
            'tls_v11': (int,),  # noqa: E501
            'tls_v12': (int,),  # noqa: E501
            'tls_v13': (int,),  # noqa: E501
            'edge_requests': (int,),  # noqa: E501
            'edge_resp_header_bytes': (int,),  # noqa: E501
            'edge_resp_body_bytes': (int,),  # noqa: E501
            'edge_hit_requests': (int,),  # noqa: E501
            'edge_miss_requests': (int,),  # noqa: E501
            'origin_fetches': (int,),  # noqa: E501
            'origin_fetch_header_bytes': (int,),  # noqa: E501
            'origin_fetch_body_bytes': (int,),  # noqa: E501
            'origin_fetch_resp_header_bytes': (int,),  # noqa: E501
            'origin_fetch_resp_body_bytes': (int,),  # noqa: E501
            'origin_revalidations': (int,),  # noqa: E501
            'origin_cache_fetches': (int,),  # noqa: E501
            'shield': (int,),  # noqa: E501
            'shield_resp_body_bytes': (int,),  # noqa: E501
            'shield_resp_header_bytes': (int,),  # noqa: E501
            'shield_fetches': (int,),  # noqa: E501
            'shield_fetch_header_bytes': (int,),  # noqa: E501
            'shield_fetch_body_bytes': (int,),  # noqa: E501
            'shield_fetch_resp_header_bytes': (int,),  # noqa: E501
            'shield_fetch_resp_body_bytes': (int,),  # noqa: E501
            'shield_revalidations': (int,),  # noqa: E501
            'shield_cache_fetches': (int,),  # noqa: E501
            'ipv6': (int,),  # noqa: E501
            'otfp': (int,),  # noqa: E501
            'otfp_resp_body_bytes': (int,),  # noqa: E501
            'otfp_resp_header_bytes': (int,),  # noqa: E501
            'otfp_shield_resp_body_bytes': (int,),  # noqa: E501
            'otfp_shield_resp_header_bytes': (int,),  # noqa: E501
            'otfp_manifests': (int,),  # noqa: E501
            'otfp_deliver_time': (float,),  # noqa: E501
            'otfp_shield_time': (float,),  # noqa: E501
            'video': (int,),  # noqa: E501
            'pci': (int,),  # noqa: E501
            'log': (int,),  # noqa: E501
            'log_bytes': (int,),  # noqa: E501
            'http2': (int,),  # noqa: E501
            'http3': (int,),  # noqa: E501
            'waf_logged': (int,),  # noqa: E501
            'waf_blocked': (int,),  # noqa: E501
            'waf_passed': (int,),  # noqa: E501
            'attack_req_body_bytes': (int,),  # noqa: E501
            'attack_req_header_bytes': (int,),  # noqa: E501
            'attack_logged_req_body_bytes': (int,),  # noqa: E501
            'attack_logged_req_header_bytes': (int,),  # noqa: E501
            'attack_blocked_req_body_bytes': (int,),  # noqa: E501
            'attack_blocked_req_header_bytes': (int,),  # noqa: E501
            'attack_passed_req_body_bytes': (int,),  # noqa: E501
            'attack_passed_req_header_bytes': (int,),  # noqa: E501
            'attack_resp_synth_bytes': (int,),  # noqa: E501
            'imgopto': (int,),  # noqa: E501
            'imgopto_resp_body_bytes': (int,),  # noqa: E501
            'imgopto_resp_header_bytes': (int,),  # noqa: E501
            'imgopto_shield_resp_body_bytes': (int,),  # noqa: E501
            'imgopto_shield_resp_header_bytes': (int,),  # noqa: E501
            'imgvideo': (int,),  # noqa: E501
            'imgvideo_frames': (int,),  # noqa: E501
            'imgvideo_resp_header_bytes': (int,),  # noqa: E501
            'imgvideo_resp_body_bytes': (int,),  # noqa: E501
            'imgvideo_shield_resp_header_bytes': (int,),  # noqa: E501
            'imgvideo_shield_resp_body_bytes': (int,),  # noqa: E501
            'imgvideo_shield': (int,),  # noqa: E501
            'imgvideo_shield_frames': (int,),  # noqa: E501
            'status_200': (int,),  # noqa: E501
            'status_204': (int,),  # noqa: E501
            'status_206': (int,),  # noqa: E501
            'status_301': (int,),  # noqa: E501
            'status_302': (int,),  # noqa: E501
            'status_304': (int,),  # noqa: E501
            'status_400': (int,),  # noqa: E501
            'status_401': (int,),  # noqa: E501
            'status_403': (int,),  # noqa: E501
            'status_404': (int,),  # noqa: E501
            'status_406': (int,),  # noqa: E501
            'status_416': (int,),  # noqa: E501
            'status_429': (int,),  # noqa: E501
            'status_500': (int,),  # noqa: E501
            'status_501': (int,),  # noqa: E501
            'status_502': (int,),  # noqa: E501
            'status_503': (int,),  # noqa: E501
            'status_504': (int,),  # noqa: E501
            'status_505': (int,),  # noqa: E501
            'status_1xx': (int,),  # noqa: E501
            'status_2xx': (int,),  # noqa: E501
            'status_3xx': (int,),  # noqa: E501
            'status_4xx': (int,),  # noqa: E501
            'status_5xx': (int,),  # noqa: E501
            'object_size_1k': (int,),  # noqa: E501
            'object_size_10k': (int,),  # noqa: E501
            'object_size_100k': (int,),  # noqa: E501
            'object_size_1m': (int,),  # noqa: E501
            'object_size_10m': (int,),  # noqa: E501
            'object_size_100m': (int,),  # noqa: E501
            'object_size_1g': (int,),  # noqa: E501
            'recv_sub_time': (float,),  # noqa: E501
            'recv_sub_count': (int,),  # noqa: E501
            'hash_sub_time': (float,),  # noqa: E501
            'hash_sub_count': (int,),  # noqa: E501
            'miss_sub_time': (float,),  # noqa: E501
            'miss_sub_count': (int,),  # noqa: E501
            'fetch_sub_time': (float,),  # noqa: E501
            'fetch_sub_count': (int,),  # noqa: E501
            'pass_sub_time': (float,),  # noqa: E501
            'pass_sub_count': (int,),  # noqa: E501
            'pipe_sub_time': (float,),  # noqa: E501
            'pipe_sub_count': (int,),  # noqa: E501
            'deliver_sub_time': (float,),  # noqa: E501
            'deliver_sub_count': (int,),  # noqa: E501
            'error_sub_time': (float,),  # noqa: E501
            'error_sub_count': (int,),  # noqa: E501
            'hit_sub_time': (float,),  # noqa: E501
            'hit_sub_count': (int,),  # noqa: E501
            'prehash_sub_time': (float,),  # noqa: E501
            'prehash_sub_count': (int,),  # noqa: E501
            'predeliver_sub_time': (float,),  # noqa: E501
            'predeliver_sub_count': (int,),  # noqa: E501
            'tls_handshake_sent_bytes': (int,),  # noqa: E501
            'hit_resp_body_bytes': (int,),  # noqa: E501
            'miss_resp_body_bytes': (int,),  # noqa: E501
            'pass_resp_body_bytes': (int,),  # noqa: E501
            'segblock_origin_fetches': (int,),  # noqa: E501
            'segblock_shield_fetches': (int,),  # noqa: E501
            'compute_requests': (int,),  # noqa: E501
            'compute_request_time_ms': (float,),  # noqa: E501
            'compute_request_time_billed_ms': (float,),  # noqa: E501
            'compute_ram_used': (int,),  # noqa: E501
            'compute_execution_time_ms': (float,),  # noqa: E501
            'compute_req_header_bytes': (int,),  # noqa: E501
            'compute_req_body_bytes': (int,),  # noqa: E501
            'compute_resp_header_bytes': (int,),  # noqa: E501
            'compute_resp_body_bytes': (int,),  # noqa: E501
            'compute_resp_status_1xx': (int,),  # noqa: E501
            'compute_resp_status_2xx': (int,),  # noqa: E501
            'compute_resp_status_3xx': (int,),  # noqa: E501
            'compute_resp_status_4xx': (int,),  # noqa: E501
            'compute_resp_status_5xx': (int,),  # noqa: E501
            'compute_bereq_header_bytes': (int,),  # noqa: E501
            'compute_bereq_body_bytes': (int,),  # noqa: E501
            'compute_beresp_header_bytes': (int,),  # noqa: E501
            'compute_beresp_body_bytes': (int,),  # noqa: E501
            'compute_bereqs': (int,),  # noqa: E501
            'compute_bereq_errors': (int,),  # noqa: E501
            'compute_resource_limit_exceeded': (int,),  # noqa: E501
            'compute_heap_limit_exceeded': (int,),  # noqa: E501
            'compute_stack_limit_exceeded': (int,),  # noqa: E501
            'compute_globals_limit_exceeded': (int,),  # noqa: E501
            'compute_guest_errors': (int,),  # noqa: E501
            'compute_runtime_errors': (int,),  # noqa: E501
            'edge_hit_resp_body_bytes': (int,),  # noqa: E501
            'edge_hit_resp_header_bytes': (int,),  # noqa: E501
            'edge_miss_resp_body_bytes': (int,),  # noqa: E501
            'edge_miss_resp_header_bytes': (int,),  # noqa: E501
            'origin_cache_fetch_resp_body_bytes': (int,),  # noqa: E501
            'origin_cache_fetch_resp_header_bytes': (int,),  # noqa: E501
            'shield_hit_requests': (int,),  # noqa: E501
            'shield_miss_requests': (int,),  # noqa: E501
            'shield_hit_resp_header_bytes': (int,),  # noqa: E501
            'shield_hit_resp_body_bytes': (int,),  # noqa: E501
            'shield_miss_resp_header_bytes': (int,),  # noqa: E501
            'shield_miss_resp_body_bytes': (int,),  # noqa: E501
            'websocket_req_header_bytes': (int,),  # noqa: E501
            'websocket_req_body_bytes': (int,),  # noqa: E501
            'websocket_resp_header_bytes': (int,),  # noqa: E501
            'websocket_resp_body_bytes': (int,),  # noqa: E501
            'websocket_bereq_header_bytes': (int,),  # noqa: E501
            'websocket_bereq_body_bytes': (int,),  # noqa: E501
            'websocket_beresp_header_bytes': (int,),  # noqa: E501
            'websocket_beresp_body_bytes': (int,),  # noqa: E501
            'websocket_conn_time_ms': (int,),  # noqa: E501
            'fanout_recv_publishes': (int,),  # noqa: E501
            'fanout_send_publishes': (int,),  # noqa: E501
            'kv_store_class_a_operations': (int,),  # noqa: E501
            'kv_store_class_b_operations': (int,),  # noqa: E501
            'object_store_class_a_operations': (int,),  # noqa: E501
            'object_store_class_b_operations': (int,),  # noqa: E501
            'fanout_req_header_bytes': (int,),  # noqa: E501
            'fanout_req_body_bytes': (int,),  # noqa: E501
            'fanout_resp_header_bytes': (int,),  # noqa: E501
            'fanout_resp_body_bytes': (int,),  # noqa: E501
            'fanout_bereq_header_bytes': (int,),  # noqa: E501
            'fanout_bereq_body_bytes': (int,),  # noqa: E501
            'fanout_beresp_header_bytes': (int,),  # noqa: E501
            'fanout_beresp_body_bytes': (int,),  # noqa: E501
            'fanout_conn_time_ms': (int,),  # noqa: E501
            'ddos_action_limit_streams_connections': (int,),  # noqa: E501
            'ddos_action_limit_streams_requests': (int,),  # noqa: E501
            'ddos_action_tarpit_accept': (int,),  # noqa: E501
            'ddos_action_tarpit': (int,),  # noqa: E501
            'ddos_action_close': (int,),  # noqa: E501
            'ddos_action_blackhole': (int,),  # noqa: E501
            'bot_challenge_starts': (int,),  # noqa: E501
            'bot_challenge_complete_tokens_passed': (int,),  # noqa: E501
            'bot_challenge_complete_tokens_failed': (int,),  # noqa: E501
            'bot_challenge_complete_tokens_checked': (int,),  # noqa: E501
            'bot_challenge_complete_tokens_disabled': (int,),  # noqa: E501
            'bot_challenge_complete_tokens_issued': (int,),  # noqa: E501
            'bot_challenges_issued': (int,),  # noqa: E501
            'bot_challenges_succeeded': (int,),  # noqa: E501
            'bot_challenges_failed': (int,),  # noqa: E501
            'service_id': (str,),  # noqa: E501
            'start_time': (int,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'requests': 'requests',  # noqa: E501
        'hits': 'hits',  # noqa: E501
        'hits_time': 'hits_time',  # noqa: E501
        'miss': 'miss',  # noqa: E501
        'miss_time': 'miss_time',  # noqa: E501
        '_pass': 'pass',  # noqa: E501
        'pass_time': 'pass_time',  # noqa: E501
        'errors': 'errors',  # noqa: E501
        'restarts': 'restarts',  # noqa: E501
        'hit_ratio': 'hit_ratio',  # noqa: E501
        'bandwidth': 'bandwidth',  # noqa: E501
        'body_size': 'body_size',  # noqa: E501
        'header_size': 'header_size',  # noqa: E501
        'req_body_bytes': 'req_body_bytes',  # noqa: E501
        'req_header_bytes': 'req_header_bytes',  # noqa: E501
        'resp_body_bytes': 'resp_body_bytes',  # noqa: E501
        'resp_header_bytes': 'resp_header_bytes',  # noqa: E501
        'bereq_body_bytes': 'bereq_body_bytes',  # noqa: E501
        'bereq_header_bytes': 'bereq_header_bytes',  # noqa: E501
        'uncacheable': 'uncacheable',  # noqa: E501
        'pipe': 'pipe',  # noqa: E501
        'synth': 'synth',  # noqa: E501
        'tls': 'tls',  # noqa: E501
        'tls_v10': 'tls_v10',  # noqa: E501
        'tls_v11': 'tls_v11',  # noqa: E501
        'tls_v12': 'tls_v12',  # noqa: E501
        'tls_v13': 'tls_v13',  # noqa: E501
        'edge_requests': 'edge_requests',  # noqa: E501
        'edge_resp_header_bytes': 'edge_resp_header_bytes',  # noqa: E501
        'edge_resp_body_bytes': 'edge_resp_body_bytes',  # noqa: E501
        'edge_hit_requests': 'edge_hit_requests',  # noqa: E501
        'edge_miss_requests': 'edge_miss_requests',  # noqa: E501
        'origin_fetches': 'origin_fetches',  # noqa: E501
        'origin_fetch_header_bytes': 'origin_fetch_header_bytes',  # noqa: E501
        'origin_fetch_body_bytes': 'origin_fetch_body_bytes',  # noqa: E501
        'origin_fetch_resp_header_bytes': 'origin_fetch_resp_header_bytes',  # noqa: E501
        'origin_fetch_resp_body_bytes': 'origin_fetch_resp_body_bytes',  # noqa: E501
        'origin_revalidations': 'origin_revalidations',  # noqa: E501
        'origin_cache_fetches': 'origin_cache_fetches',  # noqa: E501
        'shield': 'shield',  # noqa: E501
        'shield_resp_body_bytes': 'shield_resp_body_bytes',  # noqa: E501
        'shield_resp_header_bytes': 'shield_resp_header_bytes',  # noqa: E501
        'shield_fetches': 'shield_fetches',  # noqa: E501
        'shield_fetch_header_bytes': 'shield_fetch_header_bytes',  # noqa: E501
        'shield_fetch_body_bytes': 'shield_fetch_body_bytes',  # noqa: E501
        'shield_fetch_resp_header_bytes': 'shield_fetch_resp_header_bytes',  # noqa: E501
        'shield_fetch_resp_body_bytes': 'shield_fetch_resp_body_bytes',  # noqa: E501
        'shield_revalidations': 'shield_revalidations',  # noqa: E501
        'shield_cache_fetches': 'shield_cache_fetches',  # noqa: E501
        'ipv6': 'ipv6',  # noqa: E501
        'otfp': 'otfp',  # noqa: E501
        'otfp_resp_body_bytes': 'otfp_resp_body_bytes',  # noqa: E501
        'otfp_resp_header_bytes': 'otfp_resp_header_bytes',  # noqa: E501
        'otfp_shield_resp_body_bytes': 'otfp_shield_resp_body_bytes',  # noqa: E501
        'otfp_shield_resp_header_bytes': 'otfp_shield_resp_header_bytes',  # noqa: E501
        'otfp_manifests': 'otfp_manifests',  # noqa: E501
        'otfp_deliver_time': 'otfp_deliver_time',  # noqa: E501
        'otfp_shield_time': 'otfp_shield_time',  # noqa: E501
        'video': 'video',  # noqa: E501
        'pci': 'pci',  # noqa: E501
        'log': 'log',  # noqa: E501
        'log_bytes': 'log_bytes',  # noqa: E501
        'http2': 'http2',  # noqa: E501
        'http3': 'http3',  # noqa: E501
        'waf_logged': 'waf_logged',  # noqa: E501
        'waf_blocked': 'waf_blocked',  # noqa: E501
        'waf_passed': 'waf_passed',  # noqa: E501
        'attack_req_body_bytes': 'attack_req_body_bytes',  # noqa: E501
        'attack_req_header_bytes': 'attack_req_header_bytes',  # noqa: E501
        'attack_logged_req_body_bytes': 'attack_logged_req_body_bytes',  # noqa: E501
        'attack_logged_req_header_bytes': 'attack_logged_req_header_bytes',  # noqa: E501
        'attack_blocked_req_body_bytes': 'attack_blocked_req_body_bytes',  # noqa: E501
        'attack_blocked_req_header_bytes': 'attack_blocked_req_header_bytes',  # noqa: E501
        'attack_passed_req_body_bytes': 'attack_passed_req_body_bytes',  # noqa: E501
        'attack_passed_req_header_bytes': 'attack_passed_req_header_bytes',  # noqa: E501
        'attack_resp_synth_bytes': 'attack_resp_synth_bytes',  # noqa: E501
        'imgopto': 'imgopto',  # noqa: E501
        'imgopto_resp_body_bytes': 'imgopto_resp_body_bytes',  # noqa: E501
        'imgopto_resp_header_bytes': 'imgopto_resp_header_bytes',  # noqa: E501
        'imgopto_shield_resp_body_bytes': 'imgopto_shield_resp_body_bytes',  # noqa: E501
        'imgopto_shield_resp_header_bytes': 'imgopto_shield_resp_header_bytes',  # noqa: E501
        'imgvideo': 'imgvideo',  # noqa: E501
        'imgvideo_frames': 'imgvideo_frames',  # noqa: E501
        'imgvideo_resp_header_bytes': 'imgvideo_resp_header_bytes',  # noqa: E501
        'imgvideo_resp_body_bytes': 'imgvideo_resp_body_bytes',  # noqa: E501
        'imgvideo_shield_resp_header_bytes': 'imgvideo_shield_resp_header_bytes',  # noqa: E501
        'imgvideo_shield_resp_body_bytes': 'imgvideo_shield_resp_body_bytes',  # noqa: E501
        'imgvideo_shield': 'imgvideo_shield',  # noqa: E501
        'imgvideo_shield_frames': 'imgvideo_shield_frames',  # noqa: E501
        'status_200': 'status_200',  # noqa: E501
        'status_204': 'status_204',  # noqa: E501
        'status_206': 'status_206',  # noqa: E501
        'status_301': 'status_301',  # noqa: E501
        'status_302': 'status_302',  # noqa: E501
        'status_304': 'status_304',  # noqa: E501
        'status_400': 'status_400',  # noqa: E501
        'status_401': 'status_401',  # noqa: E501
        'status_403': 'status_403',  # noqa: E501
        'status_404': 'status_404',  # noqa: E501
        'status_406': 'status_406',  # noqa: E501
        'status_416': 'status_416',  # noqa: E501
        'status_429': 'status_429',  # noqa: E501
        'status_500': 'status_500',  # noqa: E501
        'status_501': 'status_501',  # noqa: E501
        'status_502': 'status_502',  # noqa: E501
        'status_503': 'status_503',  # noqa: E501
        'status_504': 'status_504',  # noqa: E501
        'status_505': 'status_505',  # noqa: E501
        'status_1xx': 'status_1xx',  # noqa: E501
        'status_2xx': 'status_2xx',  # noqa: E501
        'status_3xx': 'status_3xx',  # noqa: E501
        'status_4xx': 'status_4xx',  # noqa: E501
        'status_5xx': 'status_5xx',  # noqa: E501
        'object_size_1k': 'object_size_1k',  # noqa: E501
        'object_size_10k': 'object_size_10k',  # noqa: E501
        'object_size_100k': 'object_size_100k',  # noqa: E501
        'object_size_1m': 'object_size_1m',  # noqa: E501
        'object_size_10m': 'object_size_10m',  # noqa: E501
        'object_size_100m': 'object_size_100m',  # noqa: E501
        'object_size_1g': 'object_size_1g',  # noqa: E501
        'recv_sub_time': 'recv_sub_time',  # noqa: E501
        'recv_sub_count': 'recv_sub_count',  # noqa: E501
        'hash_sub_time': 'hash_sub_time',  # noqa: E501
        'hash_sub_count': 'hash_sub_count',  # noqa: E501
        'miss_sub_time': 'miss_sub_time',  # noqa: E501
        'miss_sub_count': 'miss_sub_count',  # noqa: E501
        'fetch_sub_time': 'fetch_sub_time',  # noqa: E501
        'fetch_sub_count': 'fetch_sub_count',  # noqa: E501
        'pass_sub_time': 'pass_sub_time',  # noqa: E501
        'pass_sub_count': 'pass_sub_count',  # noqa: E501
        'pipe_sub_time': 'pipe_sub_time',  # noqa: E501
        'pipe_sub_count': 'pipe_sub_count',  # noqa: E501
        'deliver_sub_time': 'deliver_sub_time',  # noqa: E501
        'deliver_sub_count': 'deliver_sub_count',  # noqa: E501
        'error_sub_time': 'error_sub_time',  # noqa: E501
        'error_sub_count': 'error_sub_count',  # noqa: E501
        'hit_sub_time': 'hit_sub_time',  # noqa: E501
        'hit_sub_count': 'hit_sub_count',  # noqa: E501
        'prehash_sub_time': 'prehash_sub_time',  # noqa: E501
        'prehash_sub_count': 'prehash_sub_count',  # noqa: E501
        'predeliver_sub_time': 'predeliver_sub_time',  # noqa: E501
        'predeliver_sub_count': 'predeliver_sub_count',  # noqa: E501
        'tls_handshake_sent_bytes': 'tls_handshake_sent_bytes',  # noqa: E501
        'hit_resp_body_bytes': 'hit_resp_body_bytes',  # noqa: E501
        'miss_resp_body_bytes': 'miss_resp_body_bytes',  # noqa: E501
        'pass_resp_body_bytes': 'pass_resp_body_bytes',  # noqa: E501
        'segblock_origin_fetches': 'segblock_origin_fetches',  # noqa: E501
        'segblock_shield_fetches': 'segblock_shield_fetches',  # noqa: E501
        'compute_requests': 'compute_requests',  # noqa: E501
        'compute_request_time_ms': 'compute_request_time_ms',  # noqa: E501
        'compute_request_time_billed_ms': 'compute_request_time_billed_ms',  # noqa: E501
        'compute_ram_used': 'compute_ram_used',  # noqa: E501
        'compute_execution_time_ms': 'compute_execution_time_ms',  # noqa: E501
        'compute_req_header_bytes': 'compute_req_header_bytes',  # noqa: E501
        'compute_req_body_bytes': 'compute_req_body_bytes',  # noqa: E501
        'compute_resp_header_bytes': 'compute_resp_header_bytes',  # noqa: E501
        'compute_resp_body_bytes': 'compute_resp_body_bytes',  # noqa: E501
        'compute_resp_status_1xx': 'compute_resp_status_1xx',  # noqa: E501
        'compute_resp_status_2xx': 'compute_resp_status_2xx',  # noqa: E501
        'compute_resp_status_3xx': 'compute_resp_status_3xx',  # noqa: E501
        'compute_resp_status_4xx': 'compute_resp_status_4xx',  # noqa: E501
        'compute_resp_status_5xx': 'compute_resp_status_5xx',  # noqa: E501
        'compute_bereq_header_bytes': 'compute_bereq_header_bytes',  # noqa: E501
        'compute_bereq_body_bytes': 'compute_bereq_body_bytes',  # noqa: E501
        'compute_beresp_header_bytes': 'compute_beresp_header_bytes',  # noqa: E501
        'compute_beresp_body_bytes': 'compute_beresp_body_bytes',  # noqa: E501
        'compute_bereqs': 'compute_bereqs',  # noqa: E501
        'compute_bereq_errors': 'compute_bereq_errors',  # noqa: E501
        'compute_resource_limit_exceeded': 'compute_resource_limit_exceeded',  # noqa: E501
        'compute_heap_limit_exceeded': 'compute_heap_limit_exceeded',  # noqa: E501
        'compute_stack_limit_exceeded': 'compute_stack_limit_exceeded',  # noqa: E501
        'compute_globals_limit_exceeded': 'compute_globals_limit_exceeded',  # noqa: E501
        'compute_guest_errors': 'compute_guest_errors',  # noqa: E501
        'compute_runtime_errors': 'compute_runtime_errors',  # noqa: E501
        'edge_hit_resp_body_bytes': 'edge_hit_resp_body_bytes',  # noqa: E501
        'edge_hit_resp_header_bytes': 'edge_hit_resp_header_bytes',  # noqa: E501
        'edge_miss_resp_body_bytes': 'edge_miss_resp_body_bytes',  # noqa: E501
        'edge_miss_resp_header_bytes': 'edge_miss_resp_header_bytes',  # noqa: E501
        'origin_cache_fetch_resp_body_bytes': 'origin_cache_fetch_resp_body_bytes',  # noqa: E501
        'origin_cache_fetch_resp_header_bytes': 'origin_cache_fetch_resp_header_bytes',  # noqa: E501
        'shield_hit_requests': 'shield_hit_requests',  # noqa: E501
        'shield_miss_requests': 'shield_miss_requests',  # noqa: E501
        'shield_hit_resp_header_bytes': 'shield_hit_resp_header_bytes',  # noqa: E501
        'shield_hit_resp_body_bytes': 'shield_hit_resp_body_bytes',  # noqa: E501
        'shield_miss_resp_header_bytes': 'shield_miss_resp_header_bytes',  # noqa: E501
        'shield_miss_resp_body_bytes': 'shield_miss_resp_body_bytes',  # noqa: E501
        'websocket_req_header_bytes': 'websocket_req_header_bytes',  # noqa: E501
        'websocket_req_body_bytes': 'websocket_req_body_bytes',  # noqa: E501
        'websocket_resp_header_bytes': 'websocket_resp_header_bytes',  # noqa: E501
        'websocket_resp_body_bytes': 'websocket_resp_body_bytes',  # noqa: E501
        'websocket_bereq_header_bytes': 'websocket_bereq_header_bytes',  # noqa: E501
        'websocket_bereq_body_bytes': 'websocket_bereq_body_bytes',  # noqa: E501
        'websocket_beresp_header_bytes': 'websocket_beresp_header_bytes',  # noqa: E501
        'websocket_beresp_body_bytes': 'websocket_beresp_body_bytes',  # noqa: E501
        'websocket_conn_time_ms': 'websocket_conn_time_ms',  # noqa: E501
        'fanout_recv_publishes': 'fanout_recv_publishes',  # noqa: E501
        'fanout_send_publishes': 'fanout_send_publishes',  # noqa: E501
        'kv_store_class_a_operations': 'kv_store_class_a_operations',  # noqa: E501
        'kv_store_class_b_operations': 'kv_store_class_b_operations',  # noqa: E501
        'object_store_class_a_operations': 'object_store_class_a_operations',  # noqa: E501
        'object_store_class_b_operations': 'object_store_class_b_operations',  # noqa: E501
        'fanout_req_header_bytes': 'fanout_req_header_bytes',  # noqa: E501
        'fanout_req_body_bytes': 'fanout_req_body_bytes',  # noqa: E501
        'fanout_resp_header_bytes': 'fanout_resp_header_bytes',  # noqa: E501
        'fanout_resp_body_bytes': 'fanout_resp_body_bytes',  # noqa: E501
        'fanout_bereq_header_bytes': 'fanout_bereq_header_bytes',  # noqa: E501
        'fanout_bereq_body_bytes': 'fanout_bereq_body_bytes',  # noqa: E501
        'fanout_beresp_header_bytes': 'fanout_beresp_header_bytes',  # noqa: E501
        'fanout_beresp_body_bytes': 'fanout_beresp_body_bytes',  # noqa: E501
        'fanout_conn_time_ms': 'fanout_conn_time_ms',  # noqa: E501
        'ddos_action_limit_streams_connections': 'ddos_action_limit_streams_connections',  # noqa: E501
        'ddos_action_limit_streams_requests': 'ddos_action_limit_streams_requests',  # noqa: E501
        'ddos_action_tarpit_accept': 'ddos_action_tarpit_accept',  # noqa: E501
        'ddos_action_tarpit': 'ddos_action_tarpit',  # noqa: E501
        'ddos_action_close': 'ddos_action_close',  # noqa: E501
        'ddos_action_blackhole': 'ddos_action_blackhole',  # noqa: E501
        'bot_challenge_starts': 'bot_challenge_starts',  # noqa: E501
        'bot_challenge_complete_tokens_passed': 'bot_challenge_complete_tokens_passed',  # noqa: E501
        'bot_challenge_complete_tokens_failed': 'bot_challenge_complete_tokens_failed',  # noqa: E501
        'bot_challenge_complete_tokens_checked': 'bot_challenge_complete_tokens_checked',  # noqa: E501
        'bot_challenge_complete_tokens_disabled': 'bot_challenge_complete_tokens_disabled',  # noqa: E501
        'bot_challenge_complete_tokens_issued': 'bot_challenge_complete_tokens_issued',  # noqa: E501
        'bot_challenges_issued': 'bot_challenges_issued',  # noqa: E501
        'bot_challenges_succeeded': 'bot_challenges_succeeded',  # noqa: E501
        'bot_challenges_failed': 'bot_challenges_failed',  # noqa: E501
        'service_id': 'service_id',  # noqa: E501
        'start_time': 'start_time',  # noqa: E501
    }

    read_only_vars = {
        'service_id',  # noqa: E501
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """Results - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            requests (int): Number of requests processed.. [optional]  # noqa: E501
            hits (int): Number of cache hits.. [optional]  # noqa: E501
            hits_time (float): Total amount of time spent processing cache hits (in seconds).. [optional]  # noqa: E501
            miss (int): Number of cache misses.. [optional]  # noqa: E501
            miss_time (float): Total amount of time spent processing cache misses (in seconds).. [optional]  # noqa: E501
            _pass (int): Number of requests that passed through the CDN without being cached.. [optional]  # noqa: E501
            pass_time (float): Total amount of time spent processing cache passes (in seconds).. [optional]  # noqa: E501
            errors (int): Number of cache errors.. [optional]  # noqa: E501
            restarts (int): Number of restarts performed.. [optional]  # noqa: E501
            hit_ratio (float, none_type): Ratio of cache hits to cache misses (between 0 and 1).. [optional]  # noqa: E501
            bandwidth (int): Total bytes delivered (`resp_header_bytes` + `resp_body_bytes` + `bereq_header_bytes` + `bereq_body_bytes` + `compute_resp_header_bytes` + `compute_resp_body_bytes` + `compute_bereq_header_bytes` + `compute_bereq_body_bytes` + `websocket_resp_header_bytes` + `websocket_resp_body_bytes` + `websocket_bereq_header_bytes` + `websocket_bereq_body_bytes` + `fanout_resp_header_bytes` + `fanout_resp_body_bytes` + `fanout_bereq_header_bytes` + `fanout_bereq_body_bytes`).. [optional]  # noqa: E501
            body_size (int): Total body bytes delivered (alias for resp_body_bytes).. [optional]  # noqa: E501
            header_size (int): Total header bytes delivered (alias for resp_header_bytes).. [optional]  # noqa: E501
            req_body_bytes (int): Total body bytes received.. [optional]  # noqa: E501
            req_header_bytes (int): Total header bytes received.. [optional]  # noqa: E501
            resp_body_bytes (int): Total body bytes delivered (edge_resp_body_bytes + shield_resp_body_bytes).. [optional]  # noqa: E501
            resp_header_bytes (int): Total header bytes delivered (edge_resp_header_bytes + shield_resp_header_bytes).. [optional]  # noqa: E501
            bereq_body_bytes (int): Total body bytes sent to origin.. [optional]  # noqa: E501
            bereq_header_bytes (int): Total header bytes sent to origin.. [optional]  # noqa: E501
            uncacheable (int): Number of requests that were designated uncachable.. [optional]  # noqa: E501
            pipe (int): Optional. Pipe operations performed (legacy feature).. [optional]  # noqa: E501
            synth (int): Number of requests that returned a synthetic response (i.e., response objects created with the `synthetic` VCL statement).. [optional]  # noqa: E501
            tls (int): Number of requests that were received over TLS.. [optional]  # noqa: E501
            tls_v10 (int): Number of requests received over TLS 1.0.. [optional]  # noqa: E501
            tls_v11 (int): Number of requests received over TLS 1.1.. [optional]  # noqa: E501
            tls_v12 (int): Number of requests received over TLS 1.2.. [optional]  # noqa: E501
            tls_v13 (int): Number of requests received over TLS 1.3.. [optional]  # noqa: E501
            edge_requests (int): Number of requests sent by end users to Fastly.. [optional]  # noqa: E501
            edge_resp_header_bytes (int): Total header bytes delivered from Fastly to the end user.. [optional]  # noqa: E501
            edge_resp_body_bytes (int): Total body bytes delivered from Fastly to the end user.. [optional]  # noqa: E501
            edge_hit_requests (int): Number of requests sent by end users to Fastly that resulted in a hit at the edge.. [optional]  # noqa: E501
            edge_miss_requests (int): Number of requests sent by end users to Fastly that resulted in a miss at the edge.. [optional]  # noqa: E501
            origin_fetches (int): Number of requests sent to origin.. [optional]  # noqa: E501
            origin_fetch_header_bytes (int): Total request header bytes sent to origin.. [optional]  # noqa: E501
            origin_fetch_body_bytes (int): Total request body bytes sent to origin.. [optional]  # noqa: E501
            origin_fetch_resp_header_bytes (int): Total header bytes received from origin.. [optional]  # noqa: E501
            origin_fetch_resp_body_bytes (int): Total body bytes received from origin.. [optional]  # noqa: E501
            origin_revalidations (int): Number of responses received from origin with a `304` status code in response to an `If-Modified-Since` or `If-None-Match` request. Under regular scenarios, a revalidation will imply a cache hit. However, if using Fastly Image Optimizer or segmented caching this may result in a cache miss.. [optional]  # noqa: E501
            origin_cache_fetches (int): The total number of completed requests made to backends (origins) that returned cacheable content.. [optional]  # noqa: E501
            shield (int): Number of requests from edge to the shield POP.. [optional]  # noqa: E501
            shield_resp_body_bytes (int): Total body bytes delivered via a shield.. [optional]  # noqa: E501
            shield_resp_header_bytes (int): Total header bytes delivered via a shield.. [optional]  # noqa: E501
            shield_fetches (int): Number of requests made from one Fastly POP to another, as part of shielding.. [optional]  # noqa: E501
            shield_fetch_header_bytes (int): Total request header bytes sent to a shield.. [optional]  # noqa: E501
            shield_fetch_body_bytes (int): Total request body bytes sent to a shield.. [optional]  # noqa: E501
            shield_fetch_resp_header_bytes (int): Total response header bytes sent from a shield to the edge.. [optional]  # noqa: E501
            shield_fetch_resp_body_bytes (int): Total response body bytes sent from a shield to the edge.. [optional]  # noqa: E501
            shield_revalidations (int): Number of responses received from origin with a `304` status code, in response to an `If-Modified-Since` or `If-None-Match` request to a shield. Under regular scenarios, a revalidation will imply a cache hit. However, if using segmented caching this may result in a cache miss.. [optional]  # noqa: E501
            shield_cache_fetches (int): The total number of completed requests made to shields that returned cacheable content.. [optional]  # noqa: E501
            ipv6 (int): Number of requests that were received over IPv6.. [optional]  # noqa: E501
            otfp (int): Number of responses that came from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_resp_body_bytes (int): Total body bytes delivered from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_resp_header_bytes (int): Total header bytes delivered from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_shield_resp_body_bytes (int): Total body bytes delivered via a shield for the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_shield_resp_header_bytes (int): Total header bytes delivered via a shield for the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_manifests (int): Number of responses that were manifest files from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_deliver_time (float): Total amount of time spent delivering a response from the Fastly On-the-Fly Packaging service for video-on-demand (in seconds).. [optional]  # noqa: E501
            otfp_shield_time (float): Total amount of time spent delivering a response via a shield from the Fastly On-the-Fly Packaging service for video-on-demand (in seconds).. [optional]  # noqa: E501
            video (int): Number of responses with the video segment or video manifest MIME type (i.e., application/x-mpegurl, application/vnd.apple.mpegurl, application/f4m, application/dash+xml, application/vnd.ms-sstr+xml, ideo/mp2t, audio/aac, video/f4f, video/x-flv, video/mp4, audio/mp4).. [optional]  # noqa: E501
            pci (int): Number of responses with the PCI flag turned on.. [optional]  # noqa: E501
            log (int): Number of log lines sent.. [optional]  # noqa: E501
            log_bytes (int): Total log bytes sent.. [optional]  # noqa: E501
            http2 (int): Number of requests received over HTTP/2.. [optional]  # noqa: E501
            http3 (int): Number of requests received over HTTP/3.. [optional]  # noqa: E501
            waf_logged (int): Number of requests that triggered a WAF rule and were logged.. [optional]  # noqa: E501
            waf_blocked (int): Number of requests that triggered a WAF rule and were blocked.. [optional]  # noqa: E501
            waf_passed (int): Number of requests that triggered a WAF rule and were passed.. [optional]  # noqa: E501
            attack_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule.. [optional]  # noqa: E501
            attack_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule.. [optional]  # noqa: E501
            attack_logged_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule that was logged.. [optional]  # noqa: E501
            attack_logged_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule that was logged.. [optional]  # noqa: E501
            attack_blocked_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule that was blocked.. [optional]  # noqa: E501
            attack_blocked_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule that was blocked.. [optional]  # noqa: E501
            attack_passed_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule that was passed.. [optional]  # noqa: E501
            attack_passed_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule that was passed.. [optional]  # noqa: E501
            attack_resp_synth_bytes (int): Total bytes delivered for requests that triggered a WAF rule and returned a synthetic response.. [optional]  # noqa: E501
            imgopto (int): Number of responses that came from the Fastly Image Optimizer service. If the service receives 10 requests for an image, this stat will be 10 regardless of how many times the image was transformed.. [optional]  # noqa: E501
            imgopto_resp_body_bytes (int): Total body bytes delivered from the Fastly Image Optimizer service, including shield traffic.. [optional]  # noqa: E501
            imgopto_resp_header_bytes (int): Total header bytes delivered from the Fastly Image Optimizer service, including shield traffic.. [optional]  # noqa: E501
            imgopto_shield_resp_body_bytes (int): Total body bytes delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgopto_shield_resp_header_bytes (int): Total header bytes delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo (int): Number of video responses that came from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_frames (int): Number of video frames that came from the Fastly Image Optimizer service. A video frame is an individual image within a sequence of video.. [optional]  # noqa: E501
            imgvideo_resp_header_bytes (int): Total header bytes of video delivered from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_resp_body_bytes (int): Total body bytes of video delivered from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield_resp_header_bytes (int): Total header bytes of video delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield_resp_body_bytes (int): Total body bytes of video delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield (int): Number of video responses delivered via a shield that came from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield_frames (int): Number of video frames delivered via a shield that came from the Fastly Image Optimizer service. A video frame is an individual image within a sequence of video.. [optional]  # noqa: E501
            status_200 (int): Number of responses sent with status code 200 (Success).. [optional]  # noqa: E501
            status_204 (int): Number of responses sent with status code 204 (No Content).. [optional]  # noqa: E501
            status_206 (int): Number of responses sent with status code 206 (Partial Content).. [optional]  # noqa: E501
            status_301 (int): Number of responses sent with status code 301 (Moved Permanently).. [optional]  # noqa: E501
            status_302 (int): Number of responses sent with status code 302 (Found).. [optional]  # noqa: E501
            status_304 (int): Number of responses sent with status code 304 (Not Modified).. [optional]  # noqa: E501
            status_400 (int): Number of responses sent with status code 400 (Bad Request).. [optional]  # noqa: E501
            status_401 (int): Number of responses sent with status code 401 (Unauthorized).. [optional]  # noqa: E501
            status_403 (int): Number of responses sent with status code 403 (Forbidden).. [optional]  # noqa: E501
            status_404 (int): Number of responses sent with status code 404 (Not Found).. [optional]  # noqa: E501
            status_406 (int): Number of responses sent with status code 406 (Not Acceptable).. [optional]  # noqa: E501
            status_416 (int): Number of responses sent with status code 416 (Range Not Satisfiable).. [optional]  # noqa: E501
            status_429 (int): Number of responses sent with status code 429 (Too Many Requests).. [optional]  # noqa: E501
            status_500 (int): Number of responses sent with status code 500 (Internal Server Error).. [optional]  # noqa: E501
            status_501 (int): Number of responses sent with status code 501 (Not Implemented).. [optional]  # noqa: E501
            status_502 (int): Number of responses sent with status code 502 (Bad Gateway).. [optional]  # noqa: E501
            status_503 (int): Number of responses sent with status code 503 (Service Unavailable).. [optional]  # noqa: E501
            status_504 (int): Number of responses sent with status code 504 (Gateway Timeout).. [optional]  # noqa: E501
            status_505 (int): Number of responses sent with status code 505 (HTTP Version Not Supported).. [optional]  # noqa: E501
            status_1xx (int): Number of \"Informational\" category status codes delivered.. [optional]  # noqa: E501
            status_2xx (int): Number of \"Success\" status codes delivered.. [optional]  # noqa: E501
            status_3xx (int): Number of \"Redirection\" codes delivered.. [optional]  # noqa: E501
            status_4xx (int): Number of \"Client Error\" codes delivered.. [optional]  # noqa: E501
            status_5xx (int): Number of \"Server Error\" codes delivered.. [optional]  # noqa: E501
            object_size_1k (int): Number of objects served that were under 1KB in size.. [optional]  # noqa: E501
            object_size_10k (int): Number of objects served that were between 1KB and 10KB in size.. [optional]  # noqa: E501
            object_size_100k (int): Number of objects served that were between 10KB and 100KB in size.. [optional]  # noqa: E501
            object_size_1m (int): Number of objects served that were between 100KB and 1MB in size.. [optional]  # noqa: E501
            object_size_10m (int): Number of objects served that were between 1MB and 10MB in size.. [optional]  # noqa: E501
            object_size_100m (int): Number of objects served that were between 10MB and 100MB in size.. [optional]  # noqa: E501
            object_size_1g (int): Number of objects served that were between 100MB and 1GB in size.. [optional]  # noqa: E501
            recv_sub_time (float): Time spent inside the `vcl_recv` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            recv_sub_count (int): Number of executions of the `vcl_recv` Varnish subroutine.. [optional]  # noqa: E501
            hash_sub_time (float): Time spent inside the `vcl_hash` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            hash_sub_count (int): Number of executions of the `vcl_hash` Varnish subroutine.. [optional]  # noqa: E501
            miss_sub_time (float): Time spent inside the `vcl_miss` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            miss_sub_count (int): Number of executions of the `vcl_miss` Varnish subroutine.. [optional]  # noqa: E501
            fetch_sub_time (float): Time spent inside the `vcl_fetch` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            fetch_sub_count (int): Number of executions of the `vcl_fetch` Varnish subroutine.. [optional]  # noqa: E501
            pass_sub_time (float): Time spent inside the `vcl_pass` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            pass_sub_count (int): Number of executions of the `vcl_pass` Varnish subroutine.. [optional]  # noqa: E501
            pipe_sub_time (float): Time spent inside the `vcl_pipe` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            pipe_sub_count (int): Number of executions of the `vcl_pipe` Varnish subroutine.. [optional]  # noqa: E501
            deliver_sub_time (float): Time spent inside the `vcl_deliver` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            deliver_sub_count (int): Number of executions of the `vcl_deliver` Varnish subroutine.. [optional]  # noqa: E501
            error_sub_time (float): Time spent inside the `vcl_error` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            error_sub_count (int): Number of executions of the `vcl_error` Varnish subroutine.. [optional]  # noqa: E501
            hit_sub_time (float): Time spent inside the `vcl_hit` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            hit_sub_count (int): Number of executions of the `vcl_hit` Varnish subroutine.. [optional]  # noqa: E501
            prehash_sub_time (float): Time spent inside the `vcl_prehash` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            prehash_sub_count (int): Number of executions of the `vcl_prehash` Varnish subroutine.. [optional]  # noqa: E501
            predeliver_sub_time (float): Time spent inside the `vcl_predeliver` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            predeliver_sub_count (int): Number of executions of the `vcl_predeliver` Varnish subroutine.. [optional]  # noqa: E501
            tls_handshake_sent_bytes (int): Number of bytes transferred during TLS handshake.. [optional]  # noqa: E501
            hit_resp_body_bytes (int): Total body bytes delivered for cache hits.. [optional]  # noqa: E501
            miss_resp_body_bytes (int): Total body bytes delivered for cache misses.. [optional]  # noqa: E501
            pass_resp_body_bytes (int): Total body bytes delivered for cache passes.. [optional]  # noqa: E501
            segblock_origin_fetches (int): Number of `Range` requests to origin for segments of resources when using segmented caching.. [optional]  # noqa: E501
            segblock_shield_fetches (int): Number of `Range` requests to a shield for segments of resources when using segmented caching.. [optional]  # noqa: E501
            compute_requests (int): The total number of requests that were received for your service by Fastly.. [optional]  # noqa: E501
            compute_request_time_ms (float): The total, actual amount of time used to process your requests, including active CPU time (in milliseconds).. [optional]  # noqa: E501
            compute_request_time_billed_ms (float): The total amount of request processing time you will be billed for, measured in 50 millisecond increments.. [optional]  # noqa: E501
            compute_ram_used (int): The amount of RAM used for your service by Fastly (in bytes).. [optional]  # noqa: E501
            compute_execution_time_ms (float): The amount of active CPU time used to process your requests (in milliseconds).. [optional]  # noqa: E501
            compute_req_header_bytes (int): Total header bytes received by the Compute platform.. [optional]  # noqa: E501
            compute_req_body_bytes (int): Total body bytes received by the Compute platform.. [optional]  # noqa: E501
            compute_resp_header_bytes (int): Total header bytes sent from Compute to end user.. [optional]  # noqa: E501
            compute_resp_body_bytes (int): Total body bytes sent from Compute to end user.. [optional]  # noqa: E501
            compute_resp_status_1xx (int): Number of \"Informational\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_2xx (int): Number of \"Success\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_3xx (int): Number of \"Redirection\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_4xx (int): Number of \"Client Error\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_5xx (int): Number of \"Server Error\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_bereq_header_bytes (int): Total header bytes sent to backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_bereq_body_bytes (int): Total body bytes sent to backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_beresp_header_bytes (int): Total header bytes received from backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_beresp_body_bytes (int): Total body bytes received from backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_bereqs (int): Number of backend requests started.. [optional]  # noqa: E501
            compute_bereq_errors (int): Number of backend request errors, including timeouts.. [optional]  # noqa: E501
            compute_resource_limit_exceeded (int): Number of times a guest exceeded its resource limit, includes heap, stack, globals, and code execution timeout.. [optional]  # noqa: E501
            compute_heap_limit_exceeded (int): Number of times a guest exceeded its heap limit.. [optional]  # noqa: E501
            compute_stack_limit_exceeded (int): Number of times a guest exceeded its stack limit.. [optional]  # noqa: E501
            compute_globals_limit_exceeded (int): Number of times a guest exceeded its globals limit.. [optional]  # noqa: E501
            compute_guest_errors (int): Number of times a service experienced a guest code error.. [optional]  # noqa: E501
            compute_runtime_errors (int): Number of times a service experienced a guest runtime error.. [optional]  # noqa: E501
            edge_hit_resp_body_bytes (int): Body bytes delivered for edge hits.. [optional]  # noqa: E501
            edge_hit_resp_header_bytes (int): Header bytes delivered for edge hits.. [optional]  # noqa: E501
            edge_miss_resp_body_bytes (int): Body bytes delivered for edge misses.. [optional]  # noqa: E501
            edge_miss_resp_header_bytes (int): Header bytes delivered for edge misses.. [optional]  # noqa: E501
            origin_cache_fetch_resp_body_bytes (int): Body bytes received from origin for cacheable content.. [optional]  # noqa: E501
            origin_cache_fetch_resp_header_bytes (int): Header bytes received from an origin for cacheable content.. [optional]  # noqa: E501
            shield_hit_requests (int): Number of requests that resulted in a hit at a shield.. [optional]  # noqa: E501
            shield_miss_requests (int): Number of requests that resulted in a miss at a shield.. [optional]  # noqa: E501
            shield_hit_resp_header_bytes (int): Header bytes delivered for shield hits.. [optional]  # noqa: E501
            shield_hit_resp_body_bytes (int): Body bytes delivered for shield hits.. [optional]  # noqa: E501
            shield_miss_resp_header_bytes (int): Header bytes delivered for shield misses.. [optional]  # noqa: E501
            shield_miss_resp_body_bytes (int): Body bytes delivered for shield misses.. [optional]  # noqa: E501
            websocket_req_header_bytes (int): Total header bytes received from end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_req_body_bytes (int): Total message content bytes received from end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_resp_header_bytes (int): Total header bytes sent to end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_resp_body_bytes (int): Total message content bytes sent to end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_bereq_header_bytes (int): Total header bytes sent to backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_bereq_body_bytes (int): Total message content bytes sent to backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_beresp_header_bytes (int): Total header bytes received from backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_beresp_body_bytes (int): Total message content bytes received from backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_conn_time_ms (int): Total duration of passthrough WebSocket connections with end users.. [optional]  # noqa: E501
            fanout_recv_publishes (int): Total published messages received from the publish API endpoint.. [optional]  # noqa: E501
            fanout_send_publishes (int): Total published messages sent to end users.. [optional]  # noqa: E501
            kv_store_class_a_operations (int): The total number of class a operations for the KV store.. [optional]  # noqa: E501
            kv_store_class_b_operations (int): The total number of class b operations for the KV store.. [optional]  # noqa: E501
            object_store_class_a_operations (int): Use kv_store_class_a_operations.. [optional]  # noqa: E501
            object_store_class_b_operations (int): Use kv_store_class_b_operations.. [optional]  # noqa: E501
            fanout_req_header_bytes (int): Total header bytes received from end users over Fanout connections.. [optional]  # noqa: E501
            fanout_req_body_bytes (int): Total body or message content bytes received from end users over Fanout connections.. [optional]  # noqa: E501
            fanout_resp_header_bytes (int): Total header bytes sent to end users over Fanout connections.. [optional]  # noqa: E501
            fanout_resp_body_bytes (int): Total body or message content bytes sent to end users over Fanout connections, excluding published message content.. [optional]  # noqa: E501
            fanout_bereq_header_bytes (int): Total header bytes sent to backends over Fanout connections.. [optional]  # noqa: E501
            fanout_bereq_body_bytes (int): Total body or message content bytes sent to backends over Fanout connections.. [optional]  # noqa: E501
            fanout_beresp_header_bytes (int): Total header bytes received from backends over Fanout connections.. [optional]  # noqa: E501
            fanout_beresp_body_bytes (int): Total body or message content bytes received from backends over Fanout connections.. [optional]  # noqa: E501
            fanout_conn_time_ms (int): Total duration of Fanout connections with end users.. [optional]  # noqa: E501
            ddos_action_limit_streams_connections (int): For HTTP/2, the number of connections the limit-streams action was applied to. The limit-streams action caps the allowed number of concurrent streams in a connection.. [optional]  # noqa: E501
            ddos_action_limit_streams_requests (int): For HTTP/2, the number of requests made on a connection for which the limit-streams action was taken. The limit-streams action caps the allowed number of concurrent streams in a connection.. [optional]  # noqa: E501
            ddos_action_tarpit_accept (int): The number of times the tarpit-accept action was taken. The tarpit-accept action adds a delay when accepting future connections.. [optional]  # noqa: E501
            ddos_action_tarpit (int): The number of times the tarpit action was taken. The tarpit action delays writing the response to the client.. [optional]  # noqa: E501
            ddos_action_close (int): The number of times the close action was taken. The close action aborts the connection as soon as possible. The close action takes effect either right after accept, right after the client hello, or right after the response was sent.. [optional]  # noqa: E501
            ddos_action_blackhole (int): The number of times the blackhole action was taken. The blackhole action quietly closes a TCP connection without sending a reset. The blackhole action quietly closes a TCP connection without notifying its peer (all TCP state is dropped).. [optional]  # noqa: E501
            bot_challenge_starts (int): The number of challenge-start tokens created.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_passed (int): The number of challenge-complete tokens that passed validation.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_failed (int): The number of challenge-complete tokens that failed validation.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_checked (int): The number of challenge-complete tokens checked.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_disabled (int): The number of challenge-complete tokens not checked because the feature was disabled.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_issued (int): The number of challenge-complete tokens issued. For example, issuing a challenge-complete token after a series of CAPTCHA challenges ending in success.. [optional]  # noqa: E501
            bot_challenges_issued (int): The number of challenges issued. For example, the issuance of a CAPTCHA challenge.. [optional]  # noqa: E501
            bot_challenges_succeeded (int): The number of successful challenge solutions processed. For example, a correct CAPTCHA solution.. [optional]  # noqa: E501
            bot_challenges_failed (int): The number of failed challenge solutions processed. For example, an incorrect CAPTCHA solution.. [optional]  # noqa: E501
            service_id (str): [optional]  # noqa: E501
            start_time (int): Timestamp for the start of the time period being reported. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """Results - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            requests (int): Number of requests processed.. [optional]  # noqa: E501
            hits (int): Number of cache hits.. [optional]  # noqa: E501
            hits_time (float): Total amount of time spent processing cache hits (in seconds).. [optional]  # noqa: E501
            miss (int): Number of cache misses.. [optional]  # noqa: E501
            miss_time (float): Total amount of time spent processing cache misses (in seconds).. [optional]  # noqa: E501
            _pass (int): Number of requests that passed through the CDN without being cached.. [optional]  # noqa: E501
            pass_time (float): Total amount of time spent processing cache passes (in seconds).. [optional]  # noqa: E501
            errors (int): Number of cache errors.. [optional]  # noqa: E501
            restarts (int): Number of restarts performed.. [optional]  # noqa: E501
            hit_ratio (float, none_type): Ratio of cache hits to cache misses (between 0 and 1).. [optional]  # noqa: E501
            bandwidth (int): Total bytes delivered (`resp_header_bytes` + `resp_body_bytes` + `bereq_header_bytes` + `bereq_body_bytes` + `compute_resp_header_bytes` + `compute_resp_body_bytes` + `compute_bereq_header_bytes` + `compute_bereq_body_bytes` + `websocket_resp_header_bytes` + `websocket_resp_body_bytes` + `websocket_bereq_header_bytes` + `websocket_bereq_body_bytes` + `fanout_resp_header_bytes` + `fanout_resp_body_bytes` + `fanout_bereq_header_bytes` + `fanout_bereq_body_bytes`).. [optional]  # noqa: E501
            body_size (int): Total body bytes delivered (alias for resp_body_bytes).. [optional]  # noqa: E501
            header_size (int): Total header bytes delivered (alias for resp_header_bytes).. [optional]  # noqa: E501
            req_body_bytes (int): Total body bytes received.. [optional]  # noqa: E501
            req_header_bytes (int): Total header bytes received.. [optional]  # noqa: E501
            resp_body_bytes (int): Total body bytes delivered (edge_resp_body_bytes + shield_resp_body_bytes).. [optional]  # noqa: E501
            resp_header_bytes (int): Total header bytes delivered (edge_resp_header_bytes + shield_resp_header_bytes).. [optional]  # noqa: E501
            bereq_body_bytes (int): Total body bytes sent to origin.. [optional]  # noqa: E501
            bereq_header_bytes (int): Total header bytes sent to origin.. [optional]  # noqa: E501
            uncacheable (int): Number of requests that were designated uncachable.. [optional]  # noqa: E501
            pipe (int): Optional. Pipe operations performed (legacy feature).. [optional]  # noqa: E501
            synth (int): Number of requests that returned a synthetic response (i.e., response objects created with the `synthetic` VCL statement).. [optional]  # noqa: E501
            tls (int): Number of requests that were received over TLS.. [optional]  # noqa: E501
            tls_v10 (int): Number of requests received over TLS 1.0.. [optional]  # noqa: E501
            tls_v11 (int): Number of requests received over TLS 1.1.. [optional]  # noqa: E501
            tls_v12 (int): Number of requests received over TLS 1.2.. [optional]  # noqa: E501
            tls_v13 (int): Number of requests received over TLS 1.3.. [optional]  # noqa: E501
            edge_requests (int): Number of requests sent by end users to Fastly.. [optional]  # noqa: E501
            edge_resp_header_bytes (int): Total header bytes delivered from Fastly to the end user.. [optional]  # noqa: E501
            edge_resp_body_bytes (int): Total body bytes delivered from Fastly to the end user.. [optional]  # noqa: E501
            edge_hit_requests (int): Number of requests sent by end users to Fastly that resulted in a hit at the edge.. [optional]  # noqa: E501
            edge_miss_requests (int): Number of requests sent by end users to Fastly that resulted in a miss at the edge.. [optional]  # noqa: E501
            origin_fetches (int): Number of requests sent to origin.. [optional]  # noqa: E501
            origin_fetch_header_bytes (int): Total request header bytes sent to origin.. [optional]  # noqa: E501
            origin_fetch_body_bytes (int): Total request body bytes sent to origin.. [optional]  # noqa: E501
            origin_fetch_resp_header_bytes (int): Total header bytes received from origin.. [optional]  # noqa: E501
            origin_fetch_resp_body_bytes (int): Total body bytes received from origin.. [optional]  # noqa: E501
            origin_revalidations (int): Number of responses received from origin with a `304` status code in response to an `If-Modified-Since` or `If-None-Match` request. Under regular scenarios, a revalidation will imply a cache hit. However, if using Fastly Image Optimizer or segmented caching this may result in a cache miss.. [optional]  # noqa: E501
            origin_cache_fetches (int): The total number of completed requests made to backends (origins) that returned cacheable content.. [optional]  # noqa: E501
            shield (int): Number of requests from edge to the shield POP.. [optional]  # noqa: E501
            shield_resp_body_bytes (int): Total body bytes delivered via a shield.. [optional]  # noqa: E501
            shield_resp_header_bytes (int): Total header bytes delivered via a shield.. [optional]  # noqa: E501
            shield_fetches (int): Number of requests made from one Fastly POP to another, as part of shielding.. [optional]  # noqa: E501
            shield_fetch_header_bytes (int): Total request header bytes sent to a shield.. [optional]  # noqa: E501
            shield_fetch_body_bytes (int): Total request body bytes sent to a shield.. [optional]  # noqa: E501
            shield_fetch_resp_header_bytes (int): Total response header bytes sent from a shield to the edge.. [optional]  # noqa: E501
            shield_fetch_resp_body_bytes (int): Total response body bytes sent from a shield to the edge.. [optional]  # noqa: E501
            shield_revalidations (int): Number of responses received from origin with a `304` status code, in response to an `If-Modified-Since` or `If-None-Match` request to a shield. Under regular scenarios, a revalidation will imply a cache hit. However, if using segmented caching this may result in a cache miss.. [optional]  # noqa: E501
            shield_cache_fetches (int): The total number of completed requests made to shields that returned cacheable content.. [optional]  # noqa: E501
            ipv6 (int): Number of requests that were received over IPv6.. [optional]  # noqa: E501
            otfp (int): Number of responses that came from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_resp_body_bytes (int): Total body bytes delivered from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_resp_header_bytes (int): Total header bytes delivered from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_shield_resp_body_bytes (int): Total body bytes delivered via a shield for the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_shield_resp_header_bytes (int): Total header bytes delivered via a shield for the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_manifests (int): Number of responses that were manifest files from the Fastly On-the-Fly Packaging service for video-on-demand.. [optional]  # noqa: E501
            otfp_deliver_time (float): Total amount of time spent delivering a response from the Fastly On-the-Fly Packaging service for video-on-demand (in seconds).. [optional]  # noqa: E501
            otfp_shield_time (float): Total amount of time spent delivering a response via a shield from the Fastly On-the-Fly Packaging service for video-on-demand (in seconds).. [optional]  # noqa: E501
            video (int): Number of responses with the video segment or video manifest MIME type (i.e., application/x-mpegurl, application/vnd.apple.mpegurl, application/f4m, application/dash+xml, application/vnd.ms-sstr+xml, ideo/mp2t, audio/aac, video/f4f, video/x-flv, video/mp4, audio/mp4).. [optional]  # noqa: E501
            pci (int): Number of responses with the PCI flag turned on.. [optional]  # noqa: E501
            log (int): Number of log lines sent.. [optional]  # noqa: E501
            log_bytes (int): Total log bytes sent.. [optional]  # noqa: E501
            http2 (int): Number of requests received over HTTP/2.. [optional]  # noqa: E501
            http3 (int): Number of requests received over HTTP/3.. [optional]  # noqa: E501
            waf_logged (int): Number of requests that triggered a WAF rule and were logged.. [optional]  # noqa: E501
            waf_blocked (int): Number of requests that triggered a WAF rule and were blocked.. [optional]  # noqa: E501
            waf_passed (int): Number of requests that triggered a WAF rule and were passed.. [optional]  # noqa: E501
            attack_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule.. [optional]  # noqa: E501
            attack_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule.. [optional]  # noqa: E501
            attack_logged_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule that was logged.. [optional]  # noqa: E501
            attack_logged_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule that was logged.. [optional]  # noqa: E501
            attack_blocked_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule that was blocked.. [optional]  # noqa: E501
            attack_blocked_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule that was blocked.. [optional]  # noqa: E501
            attack_passed_req_body_bytes (int): Total body bytes received from requests that triggered a WAF rule that was passed.. [optional]  # noqa: E501
            attack_passed_req_header_bytes (int): Total header bytes received from requests that triggered a WAF rule that was passed.. [optional]  # noqa: E501
            attack_resp_synth_bytes (int): Total bytes delivered for requests that triggered a WAF rule and returned a synthetic response.. [optional]  # noqa: E501
            imgopto (int): Number of responses that came from the Fastly Image Optimizer service. If the service receives 10 requests for an image, this stat will be 10 regardless of how many times the image was transformed.. [optional]  # noqa: E501
            imgopto_resp_body_bytes (int): Total body bytes delivered from the Fastly Image Optimizer service, including shield traffic.. [optional]  # noqa: E501
            imgopto_resp_header_bytes (int): Total header bytes delivered from the Fastly Image Optimizer service, including shield traffic.. [optional]  # noqa: E501
            imgopto_shield_resp_body_bytes (int): Total body bytes delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgopto_shield_resp_header_bytes (int): Total header bytes delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo (int): Number of video responses that came from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_frames (int): Number of video frames that came from the Fastly Image Optimizer service. A video frame is an individual image within a sequence of video.. [optional]  # noqa: E501
            imgvideo_resp_header_bytes (int): Total header bytes of video delivered from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_resp_body_bytes (int): Total body bytes of video delivered from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield_resp_header_bytes (int): Total header bytes of video delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield_resp_body_bytes (int): Total body bytes of video delivered via a shield from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield (int): Number of video responses delivered via a shield that came from the Fastly Image Optimizer service.. [optional]  # noqa: E501
            imgvideo_shield_frames (int): Number of video frames delivered via a shield that came from the Fastly Image Optimizer service. A video frame is an individual image within a sequence of video.. [optional]  # noqa: E501
            status_200 (int): Number of responses sent with status code 200 (Success).. [optional]  # noqa: E501
            status_204 (int): Number of responses sent with status code 204 (No Content).. [optional]  # noqa: E501
            status_206 (int): Number of responses sent with status code 206 (Partial Content).. [optional]  # noqa: E501
            status_301 (int): Number of responses sent with status code 301 (Moved Permanently).. [optional]  # noqa: E501
            status_302 (int): Number of responses sent with status code 302 (Found).. [optional]  # noqa: E501
            status_304 (int): Number of responses sent with status code 304 (Not Modified).. [optional]  # noqa: E501
            status_400 (int): Number of responses sent with status code 400 (Bad Request).. [optional]  # noqa: E501
            status_401 (int): Number of responses sent with status code 401 (Unauthorized).. [optional]  # noqa: E501
            status_403 (int): Number of responses sent with status code 403 (Forbidden).. [optional]  # noqa: E501
            status_404 (int): Number of responses sent with status code 404 (Not Found).. [optional]  # noqa: E501
            status_406 (int): Number of responses sent with status code 406 (Not Acceptable).. [optional]  # noqa: E501
            status_416 (int): Number of responses sent with status code 416 (Range Not Satisfiable).. [optional]  # noqa: E501
            status_429 (int): Number of responses sent with status code 429 (Too Many Requests).. [optional]  # noqa: E501
            status_500 (int): Number of responses sent with status code 500 (Internal Server Error).. [optional]  # noqa: E501
            status_501 (int): Number of responses sent with status code 501 (Not Implemented).. [optional]  # noqa: E501
            status_502 (int): Number of responses sent with status code 502 (Bad Gateway).. [optional]  # noqa: E501
            status_503 (int): Number of responses sent with status code 503 (Service Unavailable).. [optional]  # noqa: E501
            status_504 (int): Number of responses sent with status code 504 (Gateway Timeout).. [optional]  # noqa: E501
            status_505 (int): Number of responses sent with status code 505 (HTTP Version Not Supported).. [optional]  # noqa: E501
            status_1xx (int): Number of \"Informational\" category status codes delivered.. [optional]  # noqa: E501
            status_2xx (int): Number of \"Success\" status codes delivered.. [optional]  # noqa: E501
            status_3xx (int): Number of \"Redirection\" codes delivered.. [optional]  # noqa: E501
            status_4xx (int): Number of \"Client Error\" codes delivered.. [optional]  # noqa: E501
            status_5xx (int): Number of \"Server Error\" codes delivered.. [optional]  # noqa: E501
            object_size_1k (int): Number of objects served that were under 1KB in size.. [optional]  # noqa: E501
            object_size_10k (int): Number of objects served that were between 1KB and 10KB in size.. [optional]  # noqa: E501
            object_size_100k (int): Number of objects served that were between 10KB and 100KB in size.. [optional]  # noqa: E501
            object_size_1m (int): Number of objects served that were between 100KB and 1MB in size.. [optional]  # noqa: E501
            object_size_10m (int): Number of objects served that were between 1MB and 10MB in size.. [optional]  # noqa: E501
            object_size_100m (int): Number of objects served that were between 10MB and 100MB in size.. [optional]  # noqa: E501
            object_size_1g (int): Number of objects served that were between 100MB and 1GB in size.. [optional]  # noqa: E501
            recv_sub_time (float): Time spent inside the `vcl_recv` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            recv_sub_count (int): Number of executions of the `vcl_recv` Varnish subroutine.. [optional]  # noqa: E501
            hash_sub_time (float): Time spent inside the `vcl_hash` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            hash_sub_count (int): Number of executions of the `vcl_hash` Varnish subroutine.. [optional]  # noqa: E501
            miss_sub_time (float): Time spent inside the `vcl_miss` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            miss_sub_count (int): Number of executions of the `vcl_miss` Varnish subroutine.. [optional]  # noqa: E501
            fetch_sub_time (float): Time spent inside the `vcl_fetch` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            fetch_sub_count (int): Number of executions of the `vcl_fetch` Varnish subroutine.. [optional]  # noqa: E501
            pass_sub_time (float): Time spent inside the `vcl_pass` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            pass_sub_count (int): Number of executions of the `vcl_pass` Varnish subroutine.. [optional]  # noqa: E501
            pipe_sub_time (float): Time spent inside the `vcl_pipe` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            pipe_sub_count (int): Number of executions of the `vcl_pipe` Varnish subroutine.. [optional]  # noqa: E501
            deliver_sub_time (float): Time spent inside the `vcl_deliver` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            deliver_sub_count (int): Number of executions of the `vcl_deliver` Varnish subroutine.. [optional]  # noqa: E501
            error_sub_time (float): Time spent inside the `vcl_error` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            error_sub_count (int): Number of executions of the `vcl_error` Varnish subroutine.. [optional]  # noqa: E501
            hit_sub_time (float): Time spent inside the `vcl_hit` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            hit_sub_count (int): Number of executions of the `vcl_hit` Varnish subroutine.. [optional]  # noqa: E501
            prehash_sub_time (float): Time spent inside the `vcl_prehash` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            prehash_sub_count (int): Number of executions of the `vcl_prehash` Varnish subroutine.. [optional]  # noqa: E501
            predeliver_sub_time (float): Time spent inside the `vcl_predeliver` Varnish subroutine (in seconds).. [optional]  # noqa: E501
            predeliver_sub_count (int): Number of executions of the `vcl_predeliver` Varnish subroutine.. [optional]  # noqa: E501
            tls_handshake_sent_bytes (int): Number of bytes transferred during TLS handshake.. [optional]  # noqa: E501
            hit_resp_body_bytes (int): Total body bytes delivered for cache hits.. [optional]  # noqa: E501
            miss_resp_body_bytes (int): Total body bytes delivered for cache misses.. [optional]  # noqa: E501
            pass_resp_body_bytes (int): Total body bytes delivered for cache passes.. [optional]  # noqa: E501
            segblock_origin_fetches (int): Number of `Range` requests to origin for segments of resources when using segmented caching.. [optional]  # noqa: E501
            segblock_shield_fetches (int): Number of `Range` requests to a shield for segments of resources when using segmented caching.. [optional]  # noqa: E501
            compute_requests (int): The total number of requests that were received for your service by Fastly.. [optional]  # noqa: E501
            compute_request_time_ms (float): The total, actual amount of time used to process your requests, including active CPU time (in milliseconds).. [optional]  # noqa: E501
            compute_request_time_billed_ms (float): The total amount of request processing time you will be billed for, measured in 50 millisecond increments.. [optional]  # noqa: E501
            compute_ram_used (int): The amount of RAM used for your service by Fastly (in bytes).. [optional]  # noqa: E501
            compute_execution_time_ms (float): The amount of active CPU time used to process your requests (in milliseconds).. [optional]  # noqa: E501
            compute_req_header_bytes (int): Total header bytes received by the Compute platform.. [optional]  # noqa: E501
            compute_req_body_bytes (int): Total body bytes received by the Compute platform.. [optional]  # noqa: E501
            compute_resp_header_bytes (int): Total header bytes sent from Compute to end user.. [optional]  # noqa: E501
            compute_resp_body_bytes (int): Total body bytes sent from Compute to end user.. [optional]  # noqa: E501
            compute_resp_status_1xx (int): Number of \"Informational\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_2xx (int): Number of \"Success\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_3xx (int): Number of \"Redirection\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_4xx (int): Number of \"Client Error\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_resp_status_5xx (int): Number of \"Server Error\" category status codes delivered by the Compute platform.. [optional]  # noqa: E501
            compute_bereq_header_bytes (int): Total header bytes sent to backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_bereq_body_bytes (int): Total body bytes sent to backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_beresp_header_bytes (int): Total header bytes received from backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_beresp_body_bytes (int): Total body bytes received from backends (origins) by the Compute platform.. [optional]  # noqa: E501
            compute_bereqs (int): Number of backend requests started.. [optional]  # noqa: E501
            compute_bereq_errors (int): Number of backend request errors, including timeouts.. [optional]  # noqa: E501
            compute_resource_limit_exceeded (int): Number of times a guest exceeded its resource limit, includes heap, stack, globals, and code execution timeout.. [optional]  # noqa: E501
            compute_heap_limit_exceeded (int): Number of times a guest exceeded its heap limit.. [optional]  # noqa: E501
            compute_stack_limit_exceeded (int): Number of times a guest exceeded its stack limit.. [optional]  # noqa: E501
            compute_globals_limit_exceeded (int): Number of times a guest exceeded its globals limit.. [optional]  # noqa: E501
            compute_guest_errors (int): Number of times a service experienced a guest code error.. [optional]  # noqa: E501
            compute_runtime_errors (int): Number of times a service experienced a guest runtime error.. [optional]  # noqa: E501
            edge_hit_resp_body_bytes (int): Body bytes delivered for edge hits.. [optional]  # noqa: E501
            edge_hit_resp_header_bytes (int): Header bytes delivered for edge hits.. [optional]  # noqa: E501
            edge_miss_resp_body_bytes (int): Body bytes delivered for edge misses.. [optional]  # noqa: E501
            edge_miss_resp_header_bytes (int): Header bytes delivered for edge misses.. [optional]  # noqa: E501
            origin_cache_fetch_resp_body_bytes (int): Body bytes received from origin for cacheable content.. [optional]  # noqa: E501
            origin_cache_fetch_resp_header_bytes (int): Header bytes received from an origin for cacheable content.. [optional]  # noqa: E501
            shield_hit_requests (int): Number of requests that resulted in a hit at a shield.. [optional]  # noqa: E501
            shield_miss_requests (int): Number of requests that resulted in a miss at a shield.. [optional]  # noqa: E501
            shield_hit_resp_header_bytes (int): Header bytes delivered for shield hits.. [optional]  # noqa: E501
            shield_hit_resp_body_bytes (int): Body bytes delivered for shield hits.. [optional]  # noqa: E501
            shield_miss_resp_header_bytes (int): Header bytes delivered for shield misses.. [optional]  # noqa: E501
            shield_miss_resp_body_bytes (int): Body bytes delivered for shield misses.. [optional]  # noqa: E501
            websocket_req_header_bytes (int): Total header bytes received from end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_req_body_bytes (int): Total message content bytes received from end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_resp_header_bytes (int): Total header bytes sent to end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_resp_body_bytes (int): Total message content bytes sent to end users over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_bereq_header_bytes (int): Total header bytes sent to backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_bereq_body_bytes (int): Total message content bytes sent to backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_beresp_header_bytes (int): Total header bytes received from backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_beresp_body_bytes (int): Total message content bytes received from backends over passthrough WebSocket connections.. [optional]  # noqa: E501
            websocket_conn_time_ms (int): Total duration of passthrough WebSocket connections with end users.. [optional]  # noqa: E501
            fanout_recv_publishes (int): Total published messages received from the publish API endpoint.. [optional]  # noqa: E501
            fanout_send_publishes (int): Total published messages sent to end users.. [optional]  # noqa: E501
            kv_store_class_a_operations (int): The total number of class a operations for the KV store.. [optional]  # noqa: E501
            kv_store_class_b_operations (int): The total number of class b operations for the KV store.. [optional]  # noqa: E501
            object_store_class_a_operations (int): Use kv_store_class_a_operations.. [optional]  # noqa: E501
            object_store_class_b_operations (int): Use kv_store_class_b_operations.. [optional]  # noqa: E501
            fanout_req_header_bytes (int): Total header bytes received from end users over Fanout connections.. [optional]  # noqa: E501
            fanout_req_body_bytes (int): Total body or message content bytes received from end users over Fanout connections.. [optional]  # noqa: E501
            fanout_resp_header_bytes (int): Total header bytes sent to end users over Fanout connections.. [optional]  # noqa: E501
            fanout_resp_body_bytes (int): Total body or message content bytes sent to end users over Fanout connections, excluding published message content.. [optional]  # noqa: E501
            fanout_bereq_header_bytes (int): Total header bytes sent to backends over Fanout connections.. [optional]  # noqa: E501
            fanout_bereq_body_bytes (int): Total body or message content bytes sent to backends over Fanout connections.. [optional]  # noqa: E501
            fanout_beresp_header_bytes (int): Total header bytes received from backends over Fanout connections.. [optional]  # noqa: E501
            fanout_beresp_body_bytes (int): Total body or message content bytes received from backends over Fanout connections.. [optional]  # noqa: E501
            fanout_conn_time_ms (int): Total duration of Fanout connections with end users.. [optional]  # noqa: E501
            ddos_action_limit_streams_connections (int): For HTTP/2, the number of connections the limit-streams action was applied to. The limit-streams action caps the allowed number of concurrent streams in a connection.. [optional]  # noqa: E501
            ddos_action_limit_streams_requests (int): For HTTP/2, the number of requests made on a connection for which the limit-streams action was taken. The limit-streams action caps the allowed number of concurrent streams in a connection.. [optional]  # noqa: E501
            ddos_action_tarpit_accept (int): The number of times the tarpit-accept action was taken. The tarpit-accept action adds a delay when accepting future connections.. [optional]  # noqa: E501
            ddos_action_tarpit (int): The number of times the tarpit action was taken. The tarpit action delays writing the response to the client.. [optional]  # noqa: E501
            ddos_action_close (int): The number of times the close action was taken. The close action aborts the connection as soon as possible. The close action takes effect either right after accept, right after the client hello, or right after the response was sent.. [optional]  # noqa: E501
            ddos_action_blackhole (int): The number of times the blackhole action was taken. The blackhole action quietly closes a TCP connection without sending a reset. The blackhole action quietly closes a TCP connection without notifying its peer (all TCP state is dropped).. [optional]  # noqa: E501
            bot_challenge_starts (int): The number of challenge-start tokens created.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_passed (int): The number of challenge-complete tokens that passed validation.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_failed (int): The number of challenge-complete tokens that failed validation.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_checked (int): The number of challenge-complete tokens checked.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_disabled (int): The number of challenge-complete tokens not checked because the feature was disabled.. [optional]  # noqa: E501
            bot_challenge_complete_tokens_issued (int): The number of challenge-complete tokens issued. For example, issuing a challenge-complete token after a series of CAPTCHA challenges ending in success.. [optional]  # noqa: E501
            bot_challenges_issued (int): The number of challenges issued. For example, the issuance of a CAPTCHA challenge.. [optional]  # noqa: E501
            bot_challenges_succeeded (int): The number of successful challenge solutions processed. For example, a correct CAPTCHA solution.. [optional]  # noqa: E501
            bot_challenges_failed (int): The number of failed challenge solutions processed. For example, an incorrect CAPTCHA solution.. [optional]  # noqa: E501
            service_id (str): [optional]  # noqa: E501
            start_time (int): Timestamp for the start of the time period being reported. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    Fastly API

    Via the Fastly API you can perform any of the operations that are possible within the management console,  including creating services, domains, and backends, configuring rules or uploading your own application code, as well as account operations such as user administration and billing reports. The API is organized into collections of endpoints that allow manipulation of objects related to Fastly services and accounts. For the most accurate and up-to-date API reference content, visit our [Developer Hub](https://developer.fastly.com/reference/api/)   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: oss@fastly.com
"""


import re  # noqa: F401
import sys  # noqa: F401

from fastly.api_client import ApiClient, Endpoint as _Endpoint
from fastly.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fastly.model.inline_response200 import InlineResponse200
from fastly.model.server_response import ServerResponse


class ServerApi(object):
    """NOTE: This class is auto generated.
    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_pool_server_endpoint = _Endpoint(
            settings={
                'response_type': (ServerResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/pool/{pool_id}/server',
                'operation_id': 'create_pool_server',
                'http_method': 'POST',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'pool_id',
                    'weight',
                    'max_conn',
                    'port',
                    'address',
                    'comment',
                    'disabled',
                    'override_host',
                ],
                'required': [
                    'service_id',
                    'pool_id',
                ],
                'nullable': [
                    'comment',
                    'override_host',
                ],
                'enum': [
                ],
                'validation': [
                    'weight',
                ]
            },
            root_map={
                'validations': {
                    ('weight',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'pool_id':
                        (str,),
                    'weight':
                        (int,),
                    'max_conn':
                        (int,),
                    'port':
                        (int,),
                    'address':
                        (str,),
                    'comment':
                        (str, none_type,),
                    'disabled':
                        (bool,),
                    'override_host':
                        (str, none_type,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'pool_id': 'pool_id',
                    'weight': 'weight',
                    'max_conn': 'max_conn',
                    'port': 'port',
                    'address': 'address',
                    'comment': 'comment',
                    'disabled': 'disabled',
                    'override_host': 'override_host',
                },
                'location_map': {
                    'service_id': 'path',
                    'pool_id': 'path',
                    'weight': 'form',
                    'max_conn': 'form',
                    'port': 'form',
                    'address': 'form',
                    'comment': 'form',
                    'disabled': 'form',
                    'override_host': 'form',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )
        self.delete_pool_server_endpoint = _Endpoint(
            settings={
                'response_type': (InlineResponse200,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/pool/{pool_id}/server/{server_id}',
                'operation_id': 'delete_pool_server',
                'http_method': 'DELETE',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'pool_id',
                    'server_id',
                ],
                'required': [
                    'service_id',
                    'pool_id',
                    'server_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'pool_id':
                        (str,),
                    'server_id':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'pool_id': 'pool_id',
                    'server_id': 'server_id',
                },
                'location_map': {
                    'service_id': 'path',
                    'pool_id': 'path',
                    'server_id': 'path',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_pool_server_endpoint = _Endpoint(
            settings={
                'response_type': (ServerResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/pool/{pool_id}/server/{server_id}',
                'operation_id': 'get_pool_server',
                'http_method': 'GET',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'pool_id',
                    'server_id',
                ],
                'required': [
                    'service_id',
                    'pool_id',
                    'server_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'pool_id':
                        (str,),
                    'server_id':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'pool_id': 'pool_id',
                    'server_id': 'server_id',
                },
                'location_map': {
                    'service_id': 'path',
                    'pool_id': 'path',
                    'server_id': 'path',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_pool_servers_endpoint = _Endpoint(
            settings={
                'response_type': ([ServerResponse],),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/pool/{pool_id}/servers',
                'operation_id': 'list_pool_servers',
                'http_method': 'GET',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'pool_id',
                ],
                'required': [
                    'service_id',
                    'pool_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'pool_id':
                        (str,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'pool_id': 'pool_id',
                },
                'location_map': {
                    'service_id': 'path',
                    'pool_id': 'path',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_pool_server_endpoint = _Endpoint(
            settings={
                'response_type': (ServerResponse,),
                'auth': [
                    'token'
                ],
                'endpoint_path': '/service/{service_id}/pool/{pool_id}/server/{server_id}',
                'operation_id': 'update_pool_server',
                'http_method': 'PUT',
                'servers': [
                    {
                        'url': "https://api.fastly.com",
                        'description': "No description provided",
                    },
                ]
            },
            params_map={
                'all': [
                    'service_id',
                    'pool_id',
                    'server_id',
                    'weight',
                    'max_conn',
                    'port',
                    'address',
                    'comment',
                    'disabled',
                    'override_host',
                ],
                'required': [
                    'service_id',
                    'pool_id',
                    'server_id',
                ],
                'nullable': [
                    'comment',
                    'override_host',
                ],
                'enum': [
                ],
                'validation': [
                    'weight',
                ]
            },
            root_map={
                'validations': {
                    ('weight',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'service_id':
                        (str,),
                    'pool_id':
                        (str,),
                    'server_id':
                        (str,),
                    'weight':
                        (int,),
                    'max_conn':
                        (int,),
                    'port':
                        (int,),
                    'address':
                        (str,),
                    'comment':
                        (str, none_type,),
                    'disabled':
                        (bool,),
                    'override_host':
                        (str, none_type,),
                },
                'attribute_map': {
                    'service_id': 'service_id',
                    'pool_id': 'pool_id',
                    'server_id': 'server_id',
                    'weight': 'weight',
                    'max_conn': 'max_conn',
                    'port': 'port',
                    'address': 'address',
                    'comment': 'comment',
                    'disabled': 'disabled',
                    'override_host': 'override_host',
                },
                'location_map': {
                    'service_id': 'path',
                    'pool_id': 'path',
                    'server_id': 'path',
                    'weight': 'form',
                    'max_conn': 'form',
                    'port': 'form',
                    'address': 'form',
                    'comment': 'form',
                    'disabled': 'form',
                    'override_host': 'form',
                },
                'path_params_allow_reserved_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )

    def create_pool_server(
        self,
        service_id,
        pool_id,
        **kwargs
    ):
        """Add a server to a pool  # noqa: E501

        Creates a single server for a particular service and pool.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_pool_server(service_id, pool_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            pool_id (str): Alphanumeric string identifying a Pool.

        Keyword Args:
            weight (int): Weight (`1-100`) used to load balance this server against others.. [optional] if omitted the server will use the default value of 100
            max_conn (int): Maximum number of connections. If the value is `0`, it inherits the value from pool's `max_conn_default`.. [optional] if omitted the server will use the default value of 0
            port (int): Port number. Setting port `443` does not force TLS. Set `use_tls` in pool to force TLS.. [optional] if omitted the server will use the default value of 80
            address (str): A hostname, IPv4, or IPv6 address for the server. Required.. [optional]
            comment (str, none_type): A freeform descriptive note.. [optional]
            disabled (bool): Allows servers to be enabled and disabled in a pool.. [optional] if omitted the server will use the default value of False
            override_host (str, none_type): The hostname to override the Host header. Defaults to `null` meaning no override of the Host header if not set. This setting can also be added to a Pool definition. However, the server setting will override the Pool setting.. [optional] if omitted the server will use the default value of "null"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ServerResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['pool_id'] = \
            pool_id
        return self.create_pool_server_endpoint.call_with_http_info(**kwargs)

    def delete_pool_server(
        self,
        service_id,
        pool_id,
        server_id,
        **kwargs
    ):
        """Delete a server from a pool  # noqa: E501

        Deletes a single server for a particular service and pool.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_pool_server(service_id, pool_id, server_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            pool_id (str): Alphanumeric string identifying a Pool.
            server_id (str): Alphanumeric string identifying a Server.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            InlineResponse200
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['pool_id'] = \
            pool_id
        kwargs['server_id'] = \
            server_id
        return self.delete_pool_server_endpoint.call_with_http_info(**kwargs)

    def get_pool_server(
        self,
        service_id,
        pool_id,
        server_id,
        **kwargs
    ):
        """Get a pool server  # noqa: E501

        Gets a single server for a particular service and pool.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_pool_server(service_id, pool_id, server_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            pool_id (str): Alphanumeric string identifying a Pool.
            server_id (str): Alphanumeric string identifying a Server.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ServerResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['pool_id'] = \
            pool_id
        kwargs['server_id'] = \
            server_id
        return self.get_pool_server_endpoint.call_with_http_info(**kwargs)

    def list_pool_servers(
        self,
        service_id,
        pool_id,
        **kwargs
    ):
        """List servers in a pool  # noqa: E501

        Lists all servers for a particular service and pool.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_pool_servers(service_id, pool_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            pool_id (str): Alphanumeric string identifying a Pool.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [ServerResponse]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['pool_id'] = \
            pool_id
        return self.list_pool_servers_endpoint.call_with_http_info(**kwargs)

    def update_pool_server(
        self,
        service_id,
        pool_id,
        server_id,
        **kwargs
    ):
        """Update a server  # noqa: E501

        Updates a single server for a particular service and pool.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_pool_server(service_id, pool_id, server_id, async_req=True)
        >>> result = thread.get()

        Args:
            service_id (str): Alphanumeric string identifying the service.
            pool_id (str): Alphanumeric string identifying a Pool.
            server_id (str): Alphanumeric string identifying a Server.

        Keyword Args:
            weight (int): Weight (`1-100`) used to load balance this server against others.. [optional] if omitted the server will use the default value of 100
            max_conn (int): Maximum number of connections. If the value is `0`, it inherits the value from pool's `max_conn_default`.. [optional] if omitted the server will use the default value of 0
            port (int): Port number. Setting port `443` does not force TLS. Set `use_tls` in pool to force TLS.. [optional] if omitted the server will use the default value of 80
            address (str): A hostname, IPv4, or IPv6 address for the server. Required.. [optional]
            comment (str, none_type): A freeform descriptive note.. [optional]
            disabled (bool): Allows servers to be enabled and disabled in a pool.. [optional] if omitted the server will use the default value of False
            override_host (str, none_type): The hostname to override the Host header. Defaults to `null` meaning no override of the Host header if not set. This setting can also be added to a Pool definition. However, the server setting will override the Pool setting.. [optional] if omitted the server will use the default value of "null"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ServerResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['service_id'] = \
            service_id
        kwargs['pool_id'] = \
            pool_id
        kwargs['server_id'] = \
            server_id
        return self.update_pool_server_endpoint.call_with_http_info(**kwargs)

